@@ -33,6 +33,7 @@ static const int sc_ThumbnialListCellSpace = 4;      // 框选滚动步进
 
 GlobalStatus *GlobalStatus::instance()
 {
+    // qDebug() << "GlobalStatus::instance - Function entry/exit";
     static GlobalStatus s_instance;
     return &s_instance;
 }
@@ -52,11 +53,12 @@ GlobalStatus::GlobalStatus(QObject *parent)
 }
 
 GlobalStatus::~GlobalStatus() {
-    qDebug() << "Destroying GlobalStatus";
+    // qDebug() << "Destroying GlobalStatus";
     // 在程序退出的过程中
     // 由于析构过成功会触发destoryed信号，从而导致qml上使用GlobalStatus对象的地方触发重新绑定，
     // 但此时本对象已经析构，qml上会使用一些已经析构掉的对象，导致崩溃
     disconnect(this, nullptr, nullptr, nullptr);
+    // qDebug() << "GlobalStatus::~GlobalStatus - Function exit";
 }
 
 /**
@@ -64,6 +66,7 @@ GlobalStatus::~GlobalStatus() {
  */
 bool GlobalStatus::showFullScreen() const
 {
+    qDebug() << "GlobalStatus::showFullScreen - Function entry, returning:" << storeshowFullScreen;
     return storeshowFullScreen;
 }
 
@@ -72,11 +75,13 @@ bool GlobalStatus::showFullScreen() const
  */
 void GlobalStatus::setShowFullScreen(bool value)
 {
+    qDebug() << "GlobalStatus::setShowFullScreen - Function entry, value:" << value;
     if (value != storeshowFullScreen) {
         qDebug() << "Setting full screen from" << storeshowFullScreen << "to" << value;
         storeshowFullScreen = value;
         Q_EMIT showFullScreenChanged();
     }
+    qDebug() << "GlobalStatus::setShowFullScreen - Function exit";
 }
 
 /**
@@ -84,6 +89,7 @@ void GlobalStatus::setShowFullScreen(bool value)
  */
 bool GlobalStatus::enableNavigation() const
 {
+    qDebug() << "GlobalStatus::enableNavigation - Function entry, returning:" << storeenableNavigation;
     return storeenableNavigation;
 }
 
@@ -92,11 +98,13 @@ bool GlobalStatus::enableNavigation() const
  */
 void GlobalStatus::setEnableNavigation(bool value)
 {
+    qDebug() << "GlobalStatus::setEnableNavigation - Function entry, value:" << value;
     if (value != storeenableNavigation) {
         qDebug() << "Setting navigation enabled from" << storeenableNavigation << "to" << value;
         storeenableNavigation = value;
         Q_EMIT enableNavigationChanged();
     }
+    qDebug() << "GlobalStatus::setEnableNavigation - Function exit";
 }
 
 /**
@@ -104,6 +112,7 @@ void GlobalStatus::setEnableNavigation(bool value)
  */
 bool GlobalStatus::showRightMenu() const
 {
+    qDebug() << "GlobalStatus::showRightMenu - Function entry, returning:" << storeshowRightMenu;
     return storeshowRightMenu;
 }
 
@@ -112,11 +121,13 @@ bool GlobalStatus::showRightMenu() const
  */
 void GlobalStatus::setShowRightMenu(bool value)
 {
+    qDebug() << "GlobalStatus::setShowRightMenu - Function entry, value:" << value;
     if (value != storeshowRightMenu) {
         qDebug() << "Setting right menu visibility from" << storeshowRightMenu << "to" << value;
         storeshowRightMenu = value;
         Q_EMIT showRightMenuChanged();
     }
+    qDebug() << "GlobalStatus::setShowRightMenu - Function exit";
 }
 
 /**
@@ -124,6 +135,7 @@ void GlobalStatus::setShowRightMenu(bool value)
  */
 bool GlobalStatus::showImageInfo() const
 {
+    qDebug() << "GlobalStatus::showImageInfo - Function entry, returning:" << storeshowImageInfo;
     return storeshowImageInfo;
 }
 
@@ -132,11 +144,13 @@ bool GlobalStatus::showImageInfo() const
  */
 void GlobalStatus::setShowImageInfo(bool value)
 {
+    qDebug() << "GlobalStatus::setShowImageInfo - Function entry, value:" << value;
     if (value != storeshowImageInfo) {
         qDebug() << "Setting image info visibility from" << storeshowImageInfo << "to" << value;
         storeshowImageInfo = value;
         Q_EMIT showImageInfoChanged();
     }
+    qDebug() << "GlobalStatus::setShowImageInfo - Function exit";
 }
 
 /**
@@ -144,6 +158,7 @@ void GlobalStatus::setShowImageInfo(bool value)
  */
 bool GlobalStatus::viewInteractive() const
 {
+    qDebug() << "GlobalStatus::viewInteractive - Function entry, returning:" << storeviewInteractive;
     return storeviewInteractive;
 }
 
@@ -152,11 +167,13 @@ bool GlobalStatus::viewInteractive() const
  */
 void GlobalStatus::setViewInteractive(bool value)
 {
+    qDebug() << "GlobalStatus::setViewInteractive - Function entry, value:" << value;
     if (value != storeviewInteractive) {
         qDebug() << "Setting view interactive from" << storeviewInteractive << "to" << value;
         storeviewInteractive = value;
         Q_EMIT viewInteractiveChanged();
     }
+    qDebug() << "GlobalStatus::setViewInteractive - Function exit";
 }
 
 /**
@@ -164,6 +181,7 @@ void GlobalStatus::setViewInteractive(bool value)
  */
 bool GlobalStatus::viewFlicking() const
 {
+    qDebug() << "GlobalStatus::viewFlicking - Function entry, returning:" << storeviewFlicking;
     return storeviewFlicking;
 }
 
@@ -172,11 +190,13 @@ bool GlobalStatus::viewFlicking() const
  */
 void GlobalStatus::setViewFlicking(bool value)
 {
+    qDebug() << "GlobalStatus::setViewFlicking - Function entry, value:" << value;
     if (value != storeviewFlicking) {
         qDebug() << "Setting view flicking from" << storeviewFlicking << "to" << value;
         storeviewFlicking = value;
         Q_EMIT viewFlickingChanged();
     }
+    qDebug() << "GlobalStatus::setViewFlicking - Function exit";
 }
 
 /**
@@ -184,6 +204,7 @@ void GlobalStatus::setViewFlicking(bool value)
  */
 bool GlobalStatus::animationBlock() const
 {
+    // qDebug() << "GlobalStatus::animationBlock - Function entry, returning:" << storeanimationBlock;
     return storeanimationBlock;
 }
 
@@ -192,11 +213,13 @@ bool GlobalStatus::animationBlock() const
  */
 void GlobalStatus::setAnimationBlock(bool value)
 {
+    qDebug() << "GlobalStatus::setAnimationBlock - Function entry, value:" << value;
     if (value != storeanimationBlock) {
         qDebug() << "Setting animation block from" << storeanimationBlock << "to" << value;
         storeanimationBlock = value;
         Q_EMIT animationBlockChanged();
     }
+    qDebug() << "GlobalStatus::setAnimationBlock - Function exit";
 }
 
 /**
@@ -204,6 +227,7 @@ void GlobalStatus::setAnimationBlock(bool value)
  */
 bool GlobalStatus::fullScreenAnimating() const
 {
+    qDebug() << "GlobalStatus::fullScreenAnimating - Function entry, returning:" << storefullScreenAnimating;
     return storefullScreenAnimating;
 }
 
@@ -212,11 +236,13 @@ bool GlobalStatus::fullScreenAnimating() const
  */
 void GlobalStatus::setFullScreenAnimating(bool value)
 {
+    qDebug() << "GlobalStatus::setFullScreenAnimating - Function entry, value:" << value;
     if (value != storefullScreenAnimating) {
         qDebug() << "Setting full screen animating from" << storefullScreenAnimating << "to" << value;
         storefullScreenAnimating = value;
         Q_EMIT fullScreenAnimatingChanged();
     }
+    qDebug() << "GlobalStatus::setFullScreenAnimating - Function exit";
 }
 
 /**
@@ -224,6 +250,7 @@ void GlobalStatus::setFullScreenAnimating(bool value)
  */
 int GlobalStatus::thumbnailVaildWidth() const
 {
+    qDebug() << "GlobalStatus::thumbnailVaildWidth - Function entry, returning:" << storethumbnailVaildWidth;
     return storethumbnailVaildWidth;
 }
 
@@ -232,11 +259,13 @@ int GlobalStatus::thumbnailVaildWidth() const
  */
 void GlobalStatus::setThumbnailVaildWidth(int value)
 {
+    qDebug() << "GlobalStatus::setThumbnailVaildWidth - Function entry, value:" << value;
     if (value != storethumbnailVaildWidth) {
         qDebug() << "Setting thumbnail valid width from" << storethumbnailVaildWidth << "to" << value;
         storethumbnailVaildWidth = value;
         Q_EMIT thumbnailVaildWidthChanged();
     }
+    qDebug() << "GlobalStatus::setThumbnailVaildWidth - Function exit";
 }
 
 /**
@@ -244,6 +273,7 @@ void GlobalStatus::setThumbnailVaildWidth(int value)
  */
 Types::StackPage GlobalStatus::stackPage() const
 {
+    // qDebug() << "GlobalStatus::stackPage - Function entry, returning:" << storestackPage;
     return storestackPage;
 }
 
@@ -252,79 +282,95 @@ Types::StackPage GlobalStatus::stackPage() const
  */
 void GlobalStatus::setStackPage(Types::StackPage value)
 {
+    qDebug() << "GlobalStatus::setStackPage - Function entry, value:" << value;
     if (value != storestackPage) {
         qDebug() << "Setting stack page from" << storestackPage << "to" << value;
         storestackPage = value;
         Q_EMIT stackPageChanged();
     }
+    qDebug() << "GlobalStatus::setStackPage - Function exit";
 }
 
 bool GlobalStatus::showExportDialog() const
 {
+    qDebug() << "GlobalStatus::showExportDialog - Function entry, returning:" << storeshowExportDialog;
     return storeshowExportDialog;
 }
 
 void GlobalStatus::setShowExportDialog(bool value)
 {
+    qDebug() << "GlobalStatus::setShowExportDialog - Function entry, value:" << value;
     if (value != storeshowExportDialog) {
         qDebug() << "Setting export dialog visibility from" << storeshowExportDialog << "to" << value;
         storeshowExportDialog = value;
         Q_EMIT showExportDialogChanged();
     }
+    qDebug() << "GlobalStatus::setShowExportDialog - Function exit";
 }
 
 int GlobalStatus::minHeight() const
 {
+    // qDebug() << "GlobalStatus::minHeight - Function entry, returning:" << sc_MinHeight;
     return sc_MinHeight;
 }
 
 int GlobalStatus::minWidth() const
 {
+    // qDebug() << "GlobalStatus::minWidth - Function entry, returning:" << sc_MinWidth;
     return sc_MinWidth;
 }
 
 int GlobalStatus::minHideHeight() const
 {
+    // qDebug() << "GlobalStatus::minHideHeight - Function entry, returning:" << sc_MinHideHeight;
     return sc_MinHideHeight;
 }
 
 int GlobalStatus::floatMargin() const
 {
+    // qDebug() << "GlobalStatus::floatMargin - Function entry, returning:" << sc_FloatMargin;
     return sc_FloatMargin;
 }
 
 int GlobalStatus::titleHeight() const
 {
+    // qDebug() << "GlobalStatus::titleHeight - Function entry, returning:" << sc_TitleHeight;
     return sc_TitleHeight;
 }
 
 int GlobalStatus::thumbnailViewHeight() const
 {
+    // qDebug() << "GlobalStatus::thumbnailViewHeight - Function entry, returning:" << sc_ThumbnailViewHeight;
     return sc_ThumbnailViewHeight;
 }
 
 int GlobalStatus::showBottomY() const
 {
+    // qDebug() << "GlobalStatus::showBottomY - Function entry, returning:" << sc_ShowBottomY;
     return sc_ShowBottomY;
 }
 
 int GlobalStatus::switchImageHotspotWidth() const
 {
+    // qDebug() << "GlobalStatus::switchImageHotspotWidth - Function entry, returning:" << sc_SwitchImageHotspotWidth;
     return sc_SwitchImageHotspotWidth;
 }
 
 int GlobalStatus::actionMargin() const
 {
+    // qDebug() << "GlobalStatus::actionMargin - Function entry, returning:" << sc_ActionMargin;
     return sc_ActionMargin;
 }
 
 int GlobalStatus::rightMenuItemHeight() const
 {
+    // qDebug() << "GlobalStatus::rightMenuItemHeight - Function entry, returning:" << sc_RightMenuItemHeight;
     return sc_RightMenuItemHeight;
 }
 
 double GlobalStatus::animationDefaultDuration() const
 {
+    // qDebug() << "GlobalStatus::animationDefaultDuration - Function entry, returning:" << sc_AnimationDefaultDuration;
     return sc_AnimationDefaultDuration;
 }
 
@@ -334,6 +380,7 @@ double GlobalStatus::animationDefaultDuration() const
  */
 int GlobalStatus::pathViewItemCount() const
 {
+    // qDebug() << "GlobalStatus::pathViewItemCount - Function entry, returning:" << sc_PathViewItemCount;
     return sc_PathViewItemCount;
 }
 
@@ -365,131 +412,158 @@ void GlobalStatus::setFileControl(FileControl *fc)
         qWarning() << "Failed to get sidebar animation setting, using default: false";
         m_bEnableSidebarAnimation = false;
     }
+    qDebug() << "GlobalStatus::setFileControl - Function exit";
 }
 
 int GlobalStatus::sideBarWidth() const
 {
+    // qDebug() << "GlobalStatus::sideBarWidth - Function entry, returning:" << sc_SideBarWidth;
     return sc_SideBarWidth;
 }
 
 int GlobalStatus::statusBarHeight() const
 {
+    // qDebug() << "GlobalStatus::statusBarHeight - Function entry, returning:" << sc_StatusBarHeight;
     return sc_StatusBarHeight;
 }
 
 int GlobalStatus::collectionTopMargin() const
 {
+    // qDebug() << "GlobalStatus::collectionTopMargin - Function entry, returning:" << sc_CollectionTopMargin;
     return sc_CollectionTopMargin;
 }
 
 int GlobalStatus::thumbnailViewTitleHieght() const
 {
+    // qDebug() << "GlobalStatus::thumbnailViewTitleHieght - Function entry, returning:" << sc_ThumbnailViewTitleHieght;
     return sc_ThumbnailViewTitleHieght;
 }
 
 int GlobalStatus::verticalScrollBarWidth() const
 {
+    // qDebug() << "GlobalStatus::verticalScrollBarWidth - Function entry, returning:" << sc_VerticalScrollBarWidth;
     return sc_VerticalScrollBarWidth;
 }
 
 int GlobalStatus::rectSelScrollStep() const
 {
+    // qDebug() << "GlobalStatus::rectSelScrollStep - Function entry, returning:" << sc_RectSelScrollStep;
     return sc_RectSelScrollStep;
 }
 
 int GlobalStatus::thumbnailListRightMargin() const
 {
+    // qDebug() << "GlobalStatus::thumbnailListRightMargin - Function entry, returning:" << sc_ThumbnailListRightMargin;
     return sc_ThumbnailListRightMargin;
 }
 
 int GlobalStatus::thumbnialListCellSpace() const
 {
+    // qDebug() << "GlobalStatus::thumbnialListCellSpace - Function entry, returning:" << sc_ThumbnialListCellSpace;
     return sc_ThumbnialListCellSpace;
 }
 
 int GlobalStatus::needHideSideBarWidth() const
 {
+    // qDebug() << "GlobalStatus::needHideSideBarWidth - Function entry, returning:" << sc_NeedHideSideBarWidth;
     return sc_NeedHideSideBarWidth;
 }
 
 int GlobalStatus::animationDuration() const
 {
+    // qDebug() << "GlobalStatus::animationDuration - Function entry, returning:" << m_nAnimationDuration;
     return m_nAnimationDuration;
 }
 
 int GlobalStatus::largeImagePreviewAnimationDuration() const
 {
+    // qDebug() << "GlobalStatus::largeImagePreviewAnimationDuration - Function entry, returning:" << m_nLargeImagePreviewAnimationDuration;
     return m_nLargeImagePreviewAnimationDuration;
 }
 
 bool GlobalStatus::sidebarAnimationEnabled() const
 {
+    // qDebug() << "GlobalStatus::sidebarAnimationEnabled - Function entry, returning:" << m_bEnableSidebarAnimation;
     return m_bEnableSidebarAnimation;
 }
 
 qreal GlobalStatus::sideBarX() const
 {
+    // qDebug() << "GlobalStatus::sideBarX - Function entry, returning:" << m_sideBar_X;
     return m_sideBar_X;
 }
 
 void GlobalStatus::setSideBarX(const qreal& value)
 {
+    qDebug() << "GlobalStatus::setSideBarX - Function entry, value:" << value;
     if (!qFuzzyCompare(m_sideBar_X, value)) {
         qDebug() << "Setting sidebar X from" << m_sideBar_X << "to" << value;
         m_sideBar_X = value;
         Q_EMIT sideBarXChanged();
     }
+    qDebug() << "GlobalStatus::setSideBarX - Function exit";
 }
 
 QVariantList GlobalStatus::selectedPaths() const
 {
+    // qDebug() << "GlobalStatus::selectedPaths - Function entry, returning:" << m_selectedPaths;
     return m_selectedPaths;
 }
 
 void GlobalStatus::setSelectedPaths(const QVariantList& value)
 {
+    qDebug() << "GlobalStatus::setSelectedPaths - Function entry, value:" << value;
     if (m_selectedPaths != value) {
         qDebug() << "Setting selected paths, count:" << value.size();
         m_selectedPaths = value;
         Q_EMIT selectedPathsChanged();
     }
+    qDebug() << "GlobalStatus::setSelectedPaths - Function exit";
 }
 
 bool GlobalStatus::bRefreshFavoriteIconFlag() const
 {
+    // qDebug() << "GlobalStatus::bRefreshFavoriteIconFlag - Function entry, returning:" << m_bRefreshFavoriteIconFlag;
     return m_bRefreshFavoriteIconFlag;
 }
 
 void GlobalStatus::setBRefreshFavoriteIconFlag(const bool& value)
 {
+    qDebug() << "GlobalStatus::setBRefreshFavoriteIconFlag - Function entry, value:" << value;
     if (m_bRefreshFavoriteIconFlag != value) {
         qDebug() << "Setting refresh favorite icon flag from" << m_bRefreshFavoriteIconFlag << "to" << value;
         m_bRefreshFavoriteIconFlag = value;
         Q_EMIT bRefreshFavoriteIconFlagChanged();
     }
+    qDebug() << "GlobalStatus::setBRefreshFavoriteIconFlag - Function exit";
 }
 
 bool GlobalStatus::refreshRangeBtnState() const
 {
+    // qDebug() << "GlobalStatus::refreshRangeBtnState - Function entry, returning:" << m_bRefreshRangeBtnState;
     return m_bRefreshRangeBtnState;
 }
 
 void GlobalStatus::setRefreshRangeBtnState(const bool& value)
 {
+    qDebug() << "GlobalStatus::setRefreshRangeBtnState - Function entry, value:" << value;
     if (m_bRefreshRangeBtnState != value) {
         qDebug() << "Setting refresh range button state from" << m_bRefreshRangeBtnState << "to" << value;
         m_bRefreshRangeBtnState = value;
         Q_EMIT refreshRangeBtnStateChanged();
     }
+    qDebug() << "GlobalStatus::setRefreshRangeBtnState - Function exit";
 }
 
 Types::ThumbnailViewType GlobalStatus::currentViewType() const
 {
+    // qDebug() << "GlobalStatus::currentViewType - Function entry, returning:" << m_currentViewType;
     return m_currentViewType;
 }
 
 void GlobalStatus::setCurrentViewType(const Types::ThumbnailViewType &value)
 {
+    qDebug() << "GlobalStatus::setCurrentViewType - Function entry, value:" << value;
     if (m_currentViewType != value) {
         qDebug() << "Setting current view type from" << m_currentViewType << "to" << value;
         m_currentViewType = value;
@@ -514,15 +588,18 @@ void GlobalStatus::setCurrentViewType(const Types::ThumbnailViewType &value)
         }
         Q_EMIT currentViewTypeChanged();
     }
+    qDebug() << "GlobalStatus::setCurrentViewType - Function exit";
 }
 
 int GlobalStatus::currentCollecttionViewIndex() const
 {
+    // qDebug() << "GlobalStatus::currentCollecttionViewIndex - Function entry, returning:" << m_currentCollecttionViewIndex;
     return m_currentCollecttionViewIndex;
 }
 
 void GlobalStatus::setCurrentCollecttionViewIndex(const int &value)
 {
+    qDebug() << "GlobalStatus::setCurrentCollecttionViewIndex - Function entry, value:" << value;
     if (m_currentCollecttionViewIndex != value) {
         qDebug() << "Setting collection view index from" << m_currentCollecttionViewIndex << "to" << value;
         m_currentCollecttionViewIndex = value;
@@ -530,44 +607,53 @@ void GlobalStatus::setCurrentCollecttionViewIndex(const int &value)
         setBackingToMainAlbumView(false);
         Q_EMIT currentCollecttionViewIndexChanged();
     }
+    qDebug() << "GlobalStatus::setCurrentCollecttionViewIndex - Function exit";
 }
 
 Types::SwitchType GlobalStatus::currentSwitchType() const
 {
+    // qDebug() << "GlobalStatus::currentSwitchType - Function entry, returning:" << m_currentSwitchType;
     return m_currentSwitchType;
 }
 
 void GlobalStatus::setCurrentSwitchType(const int &value)
 {
+    qDebug() << "GlobalStatus::setCurrentSwitchType - Function entry, value:" << value;
     if (m_currentSwitchType != value) {
         qDebug() << "Setting switch type from" << m_currentSwitchType << "to" << value;
         m_currentSwitchType = static_cast<Types::SwitchType>(value);
         Q_EMIT currentSwitchTypeChanged();
     }
+    qDebug() << "GlobalStatus::setCurrentSwitchType - Function exit";
 }
 
 int GlobalStatus::currentCustomAlbumUId() const
 {
+    // qDebug() << "GlobalStatus::currentCustomAlbumUId - Function entry, returning:" << m_currentCustomAlbumUId;
     return m_currentCustomAlbumUId;
 }
 
 void GlobalStatus::setCurrentCustomAlbumUId(const int &value)
 {
+    qDebug() << "GlobalStatus::setCurrentCustomAlbumUId - Function entry, value:" << value;
     if (m_currentCustomAlbumUId != value) {
         qDebug() << "Setting custom album UID from" << m_currentCustomAlbumUId << "to" << value;
         setBackingToMainAlbumView(false);
         m_currentCustomAlbumUId = value;
         Q_EMIT currentCustomAlbumUIdChanged();
     }
+    qDebug() << "GlobalStatus::setCurrentCustomAlbumUId - Function exit";
 }
 
 int GlobalStatus::stackControlCurrent() const
 {
+    // qDebug() << "GlobalStatus::stackControlCurrent - Function entry, returning:" << m_stackControlCurrent;
     return m_stackControlCurrent;
 }
 
 void GlobalStatus::setStackControlCurrent(const int &value)
 {
+    qDebug() << "GlobalStatus::setStackControlCurrent - Function entry, value:" << value;
     if (m_stackControlCurrent != value) {
         qDebug() << "Setting stack control current from" << m_stackControlCurrent << "to" << value;
 
@@ -581,28 +667,34 @@ void GlobalStatus::setStackControlCurrent(const int &value)
         m_stackControlCurrent = value;
         Q_EMIT stackControlCurrentChanged();
     }
+    qDebug() << "GlobalStatus::setStackControlCurrent - Function exit";
 }
 
 int GlobalStatus::stackControlLastCurrent() const
 {
+    // qDebug() << "GlobalStatus::stackControlLastCurrent - Function entry, returning:" << m_stackControlLastCurrent;
     return m_stackControlLastCurrent;
 }
 
 void GlobalStatus::setStackControlLastCurrent(const int &value)
 {
+    qDebug() << "GlobalStatus::setStackControlLastCurrent - Function entry, value:" << value;
     if (m_stackControlLastCurrent != value) {
         m_stackControlLastCurrent = value;
         Q_EMIT stackControlLastCurrentChanged();
     }
+    qDebug() << "GlobalStatus::setStackControlLastCurrent - Function exit";
 }
 
 int GlobalStatus::thumbnailSizeLevel() const
 {
+    // qDebug() << "GlobalStatus::thumbnailSizeLevel - Function entry, returning:" << m_thumbnailSizeLevel;
     return m_thumbnailSizeLevel;
 }
 
 void GlobalStatus::setThumbnailSizeLevel(const int &value)
 {
+    qDebug() << "GlobalStatus::setThumbnailSizeLevel - Function entry, value:" << value;
     if (m_thumbnailSizeLevel != value) {
         qDebug() << "Setting thumbnail size level from" << m_thumbnailSizeLevel << "to" << value;
         m_thumbnailSizeLevel = value;
@@ -614,142 +706,172 @@ void GlobalStatus::setThumbnailSizeLevel(const int &value)
         qDebug() << "Adjusting cell base width to:" << newCellBaseWidth;
         setCellBaseWidth(newCellBaseWidth);
     }
+    qDebug() << "GlobalStatus::setThumbnailSizeLevel - Function exit";
 }
 
 qreal GlobalStatus::cellBaseWidth() const
 {
+    // qDebug() << "GlobalStatus::cellBaseWidth - Function entry, returning:" << m_cellBaseWidth;
     return m_cellBaseWidth;
 }
 
 void GlobalStatus::setCellBaseWidth(const qreal& value)
 {
+    qDebug() << "GlobalStatus::setCellBaseWidth - Function entry, value:" << value;
     if (!qFuzzyCompare(m_cellBaseWidth, value)) {
         qDebug() << "Setting cell base width from" << m_cellBaseWidth << "to" << value;
         m_cellBaseWidth = value;
         Q_EMIT cellBaseWidthChanged();
     }
+    qDebug() << "GlobalStatus::setCellBaseWidth - Function exit";
 }
 
 QString GlobalStatus::statusBarNumText() const
 {
+    // qDebug() << "GlobalStatus::statusBarNumText - Function entry, returning:" << m_statusBarNumText;
     return m_statusBarNumText;
 }
 
 void GlobalStatus::setStatusBarNumText(const QString &value)
 {
+    qDebug() << "GlobalStatus::setStatusBarNumText - Function entry, value:" << value;
     if (m_statusBarNumText != value) {
         qDebug() << "Setting status bar text from" << m_statusBarNumText << "to" << value;
         m_statusBarNumText = value;
         Q_EMIT statusBarNumTextChanged();
     }
+    qDebug() << "GlobalStatus::setStatusBarNumText - Function exit";
 }
 
 QString GlobalStatus::searchEditText() const
 {
+    // qDebug() << "GlobalStatus::searchEditText - Function entry, returning:" << m_searchEditText;
     return m_searchEditText;
 }
 
 void GlobalStatus::setSearchEditText(const QString &value)
 {
+    qDebug() << "GlobalStatus::setSearchEditText - Function entry, value:" << value;
     if (m_searchEditText != value) {
         qDebug() << "Setting search edit text from" << m_searchEditText << "to" << value;
         m_searchEditText = value;
         Q_EMIT searchEditTextChanged();
     }
+    qDebug() << "GlobalStatus::setSearchEditText - Function exit";
 }
 
 bool GlobalStatus::albumImportChangeList() const
 {
+    // qDebug() << "GlobalStatus::albumImportChangeList - Function entry, returning:" << m_bAlbumImportChangeList;
     return m_bAlbumImportChangeList;
 }
 
 void GlobalStatus::setAlbumImportChangeList(const bool &value)
 {
+    qDebug() << "GlobalStatus::setAlbumImportChangeList - Function entry, value:" << value;
     if (m_bAlbumImportChangeList != value) {
         qDebug() << "Setting album import change list from" << m_bAlbumImportChangeList << "to" << value;
         m_bAlbumImportChangeList = value;
         Q_EMIT albumImportChangeListChanged();
     }
+    qDebug() << "GlobalStatus::setAlbumImportChangeList - Function exit";
 }
 
 bool GlobalStatus::albumChangeList() const
 {
+    // qDebug() << "GlobalStatus::albumChangeList - Function entry, returning:" << m_bAlbumChangeList;
     return  m_bAlbumChangeList;
 }
 
 void GlobalStatus::setAlbumChangeList(const bool &value)
 {
+    qDebug() << "GlobalStatus::setAlbumChangeList - Function entry, value:" << value;
     if (m_bAlbumChangeList != value) {
         qDebug() << "Setting album change list from" << m_bAlbumChangeList << "to" << value;
         m_bAlbumChangeList = value;
         Q_EMIT albumChangeListChanged();
     }
+    qDebug() << "GlobalStatus::setAlbumChangeList - Function exit";
 }
 
 bool GlobalStatus::sideBarIsVisible() const
 {
+    // qDebug() << "GlobalStatus::sideBarIsVisible - Function entry, returning:" << m_bSideBarIsVisible;
     return  m_bSideBarIsVisible;
 }
 
 void GlobalStatus::setSideBarIsVisible(const bool &value)
 {
+    qDebug() << "GlobalStatus::setSideBarIsVisible - Function entry, value:" << value;
     if (m_bSideBarIsVisible != value) {
         qDebug() << "Setting sidebar visibility from" << m_bSideBarIsVisible << "to" << value;
         m_bSideBarIsVisible = value;
         Q_EMIT sideBarIsVisibleChanged();
     }
+    qDebug() << "GlobalStatus::setSideBarIsVisible - Function exit";
 }
 
 QString GlobalStatus::currentDeviceName() const
 {
+    // qDebug() << "GlobalStatus::currentDeviceName - Function entry, returning:" << m_currentDeviceName;
     return m_currentDeviceName;
 }
 
 void GlobalStatus::setCurrentDeviceName(const QString &value)
 {
+    qDebug() << "GlobalStatus::setCurrentDeviceName - Function entry, value:" << value;
     if (m_currentDeviceName != value) {
         qDebug() << "Setting current device name from" << m_currentDeviceName << "to" << value;
         m_currentDeviceName = value;
         Q_EMIT currentDeviceNameChanged();
     }
+    qDebug() << "GlobalStatus::setCurrentDeviceName - Function exit";
 }
 
 QString GlobalStatus::currentDevicePath() const
 {
+    // qDebug() << "GlobalStatus::currentDevicePath - Function entry, returning:" << m_currentDevicePath;
     return m_currentDevicePath;
 }
 
 void GlobalStatus::setCurrentDevicePath(const QString &value)
 {
+    qDebug() << "GlobalStatus::setCurrentDevicePath - Function entry, value:" << value;
     if (m_currentDevicePath != value) {
         qDebug() << "Setting current device path from" << m_currentDevicePath << "to" << value;
         m_currentDevicePath = value;
         m_currentDeviceName = AlbumControl::instance()->getDeviceName(m_currentDevicePath);
         Q_EMIT currentDevicePathChanged();
     }
+    qDebug() << "GlobalStatus::setCurrentDevicePath - Function exit";
 }
 
 bool GlobalStatus::windowDisactived() const
 {
+    // qDebug() << "GlobalStatus::windowDisactived - Function entry, returning:" << m_bWindowDisactived;
     return m_bWindowDisactived;
 }
 
 void GlobalStatus::setWindowDisactived(const bool &value)
 {
+    qDebug() << "GlobalStatus::setWindowDisactived - Function entry, value:" << value;
     if (m_bWindowDisactived != value) {
         qDebug() << "Setting window deactivated from" << m_bWindowDisactived << "to" << value;
         m_bWindowDisactived = value;
         Q_EMIT windowDisactivedChanged();
     }
+    qDebug() << "GlobalStatus::setWindowDisactived - Function exit";
 }
 
 bool GlobalStatus::loading() const
 {
+    // qDebug() << "GlobalStatus::loading - Function entry, returning:" << m_bLoading;
     return m_bLoading;
 }
 
 void GlobalStatus::setLoading(const bool &value)
 {
+    qDebug() << "GlobalStatus::setLoading - Function entry, value:" << value;
     if (m_bLoading != value) {
         qDebug() << "Setting loading state from" << m_bLoading << "to" << value;
         m_bLoading = value;
@@ -759,63 +881,76 @@ void GlobalStatus::setLoading(const bool &value)
         }
         Q_EMIT loadingChanged();
     }
+    qDebug() << "GlobalStatus::setLoading - Function exit";
 }
 
 bool GlobalStatus::enableRatioAnimation() const
 {
+    // qDebug() << "GlobalStatus::enableRatioAnimation - Function entry, returning:" << m_bEnableRatioAnimation;
     return m_bEnableRatioAnimation;
 }
 
 void GlobalStatus::setEnableRatioAnimation(const bool &value)
 {
+    qDebug() << "GlobalStatus::setEnableRatioAnimation - Function entry, value:" << value;
     if (m_bEnableRatioAnimation != value) {
         qDebug() << "Setting ratio animation from" << m_bEnableRatioAnimation << "to" << value;
         m_bEnableRatioAnimation = value;
         Q_EMIT enableRatioAnimationChanged();
     }
+    qDebug() << "GlobalStatus::setEnableRatioAnimation - Function exit";
 }
 
 bool GlobalStatus::enableFadeInoutAnimation() const
 {
+    // qDebug() << "GlobalStatus::enableFadeInoutAnimation - Function entry, returning:" << m_bEnableFadeInoutAnimation;
     return m_bEnableFadeInoutAnimation;
 
 }
 
 void GlobalStatus::setEnableFadeInoutAnimation(const bool &value)
 {
+    qDebug() << "GlobalStatus::setEnableFadeInoutAnimation - Function entry, value:" << value;
     if (m_bEnableFadeInoutAnimation != value) {
         qDebug() << "Setting fade in/out animation from" << m_bEnableFadeInoutAnimation << "to" << value;
         m_bEnableFadeInoutAnimation = value;
         Q_EMIT enableFadeInoutAnimationChanged();
     }
+    qDebug() << "GlobalStatus::setEnableFadeInoutAnimation - Function exit";
 }
 
 bool GlobalStatus::enteringImageViewer() const
 {
+    // qDebug() << "GlobalStatus::enteringImageViewer - Function entry, returning:" << m_bEnteringImageViewer;
     return m_bEnteringImageViewer;
 }
 
 void GlobalStatus::setEnteringImageViewer(const bool &value)
 {
+    qDebug() << "GlobalStatus::setEnteringImageViewer - Function entry, value:" << value;
     if (m_bEnteringImageViewer != value) {
         qDebug() << "Setting entering image viewer from" << m_bEnteringImageViewer << "to" << value;
         m_bEnteringImageViewer = value;
         Q_EMIT enteringImageViewerChanged();
     }
+    qDebug() << "GlobalStatus::setEnteringImageViewer - Function exit";
 }
 
 bool GlobalStatus::backingToMainAlbumView() const
 {
+    // qDebug() << "GlobalStatus::backingToMainAlbumView - Function entry, returning:" << m_bBackingToMainAlbumView;
     return m_bBackingToMainAlbumView;
 }
 
 void GlobalStatus::setBackingToMainAlbumView(const bool &value)
 {
+    qDebug() << "GlobalStatus::setBackingToMainAlbumView - Function entry, value:" << value;
     if (m_bBackingToMainAlbumView != value) {
         qDebug() << "Setting backing to main album view from" << m_bBackingToMainAlbumView << "to" << value;
         m_bBackingToMainAlbumView = value;
         Q_EMIT backingToMainAlbumViewChanged();
     }
+    qDebug() << "GlobalStatus::setBackingToMainAlbumView - Function exit";
 }
 
 void GlobalStatus::initConnect()
@@ -847,10 +982,12 @@ void GlobalStatus::initConnect()
         qDebug() << "Refreshing sidebar import album list";
         setAlbumImportChangeList(!m_bAlbumImportChangeList);
     });
+    qDebug() << "GlobalStatus::initConnect - Function exit";
 }
 
 QString GlobalStatus::getSelectedNumText(const QStringList &paths, const QString &text, const QString &devicePath)
 {
+    qDebug() << "GlobalStatus::getSelectedNumText - Function entry, paths:" << paths << "text:" << text << "devicePath:" << devicePath;
     QList<int> ret = AlbumControl::instance()->getPicVideoCountFromPaths(paths, devicePath);
 
     //QML的翻译不支持%n的特性，只能拆成这种代码
@@ -877,5 +1014,6 @@ QString GlobalStatus::getSelectedNumText(const QStringList &paths, const QString
         selectedNumText = tr("%1 items selected (%2 photos, %3 videos)").arg(photoCount + videoCount).arg(photoCount).arg(videoCount);
     }
 
+    qDebug() << "GlobalStatus::getSelectedNumText - Function exit, returning:" << selectedNumText;
     return selectedNumText;
 }
