@@ -4,15 +4,16 @@
 
 #include "ocrinterface.h"
 #include <QDBusMetaType>
+#include <QDebug>
 
 OcrInterface::OcrInterface(const QString &serviceName, const QString &ObjectPath,
                            const QDBusConnection &connection, QObject *parent)
     : QDBusAbstractInterface(serviceName, ObjectPath, staticInterfaceName(), connection, parent)
 {
-
+    // qDebug() << "OcrInterface::OcrInterface - Function entry";
 }
 
 OcrInterface::~OcrInterface()
 {
-
+    // qDebug() << "OcrInterface::~OcrInterface - Function entry";
 }
