@@ -16,6 +16,7 @@ ImageDataModel::ImageDataModel(QObject *parent)
     , m_albumID(-1)
     , m_keyWord("")
     , m_dayToken("")
+    , m_className("")
 {
     qDebug() << "Initializing ImageDataModel";
     connect(AlbumControl::instance(), &AlbumControl::deviceAlbumInfoLoadFinished, this, &ImageDataModel::onDeviceDataLoaded);
@@ -39,6 +40,7 @@ QHash<int, QByteArray> ImageDataModel::roleNames() const
 
 QVariant ImageDataModel::data(const QModelIndex &index, int role) const
 {
+    // qDebug() << "ImageDataModel::data - Entry";
     if (!index.isValid()) {
         qWarning() << "Invalid index requested:" << index.row() << "role:" << role;
         return {};
@@ -48,14 +50,17 @@ QVariant ImageDataModel::data(const QModelIndex &index, int role) const
 
     switch (role) {
     case Qt::DisplayRole: {
+        // qDebug() << "role is Qt::DisplayRole";
         return QVariant::fromValue(info);
     }
 
     case Roles::FileNameRole: {
+        // qDebug() << "role is Roles::FileNameRole";
         return QUrl::fromLocalFile(info.filePath).fileName();
     }
 
     case Roles::UrlRole: {
+        // qDebug() << "role is Roles::UrlRole";
         QString filePath = "";
         if (Types::RecentlyDeleted == m_modelType) {
             filePath = AlbumControl::instance()->getDeleteFullPath(LibUnionImage_NameSpace::hashByString(info.filePath), DBImgInfo::getFileNameFromFilePath(info.filePath));
@@ -67,18 +72,22 @@ QVariant ImageDataModel::data(const QModelIndex &index, int role) const
     }
 
     case Roles::FilePathRole: {
+        // qDebug() << "role is Roles::FilePathRole";
         return info.filePath;
     }
 
     case Roles::PathHashRole: {
+        // qDebug() << "role is Roles::PathHashRole";
         return info.pathHash;
     }
 
     case Roles::RemainDaysRole: {
+        // qDebug() << "role is Roles::RemainDaysRole";
         return info.remainDays;
     }
 
     case Roles::ItemTypeRole: {
+        // qDebug() << "role is Roles::ItemTypeRole";
         if (info.itemType == ItemTypePic) {
             return "picture";
         } else if (info.itemType == ItemTypeVideo) {
@@ -89,11 +98,12 @@ QVariant ImageDataModel::data(const QModelIndex &index, int role) const
     }
 
     case Roles::ItemTypeFlagRole: {
+        // qDebug() << "role is Roles::ItemTypeFlagRole";
         return info.itemType;
     }
     }
 
-    qWarning() << "Unknown role requested:" << role;
+    // qWarning() << "Unknown role requested:" << role;
     return {};
 }
 
@@ -196,6 +206,21 @@ void ImageDataModel::setImportTitle(QString importTitle)
     m_importTitle = importTitle;
 }
 
+QString ImageDataModel::className()
+{
+    return m_className;
+}
+
+void ImageDataModel::setClassName(QString className)
+{
+    if (m_className != className) {
+        qDebug() << "Setting class name from" << m_className << "to" << className;
+        emit classNameChanged();
+    }
+
+    m_className = className;
+}
+
 DBImgInfo ImageDataModel::dataForIndex(const QModelIndex &index) const
 {
     if (!index.isValid()) {
@@ -211,7 +236,7 @@ void ImageDataModel::loadData(Types::ItemType type)
     QElapsedTimer time;
     time.start();
     qDebug() << "Loading data for type:" << type << "model type:" << m_modelType;
-    
+
     m_loadType = ItemTypeNull;
     if (type == Types::All)
         m_loadType = ItemTypeNull;
@@ -247,6 +272,9 @@ void ImageDataModel::loadData(Types::ItemType type)
     } else if (m_modelType == Types::HaveImported) {
         qDebug() << "Loading imported data for title:" << m_importTitle;
         m_infoList = DBManager::instance()->getInfosByImportTimeline(QDateTime::fromString(m_importTitle, "yyyy/MM/dd hh:mm"), m_loadType);
+    } else if (m_modelType == Types::ClassificationDetail) {
+        qDebug() << "Loading classification detail data for " << m_className;
+        m_infoList = DBManager::instance()->getInfosForClass(m_className);
     }
     endResetModel();
     qDebug() << QString("loadData modelType:[%1] cost [%2]ms, loaded [%3] items").arg(m_modelType).arg(time.elapsed()).arg(m_infoList.size());
