@@ -6,19 +6,24 @@
 
 #include <QApplication>
 #include <QStyleOptionRubberBand>
+#include <QDebug>
 
 RubberBand::RubberBand(QQuickItem *parent)
     : QQuickPaintedItem(parent)
 {
+    qDebug() << "RubberBand::RubberBand - Constructor entry";
 }
 
 RubberBand::~RubberBand()
 {
+    // qDebug() << "RubberBand::~RubberBand - Destructor entry";
 }
 
 void RubberBand::paint(QPainter *painter)
 {
+    // qDebug() << "RubberBand::paint - Function entry";
     if (!qApp || !qApp->style()) {
+        // qDebug() << "RubberBand::paint - Branch: no app or style, returning";
         return;
     }
 
@@ -31,10 +36,12 @@ void RubberBand::paint(QPainter *painter)
     opt.opaque = false;
     opt.rect = contentsBoundingRect().toRect();
     qApp->style()->drawControl(QStyle::CE_RubberBand, &opt, painter);
+    // qDebug() << "RubberBand::paint - Function exit";
 }
 
 bool RubberBand::intersects(const QRectF &rect) const
 {
+    // qDebug() << "RubberBand::intersects - Function entry, rect:" << rect;
     return m_geometry.intersects(rect);
 }
 
@@ -44,6 +51,7 @@ void RubberBand::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeo
 void RubberBand::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
 #endif
 {
+    // qDebug() << "RubberBand::geometryChanged/Change - Function entry, newGeometry:" << newGeometry << "oldGeometry:" << oldGeometry;
     Q_UNUSED(oldGeometry);
 
     m_geometry = newGeometry;
@@ -52,4 +60,5 @@ void RubberBand::geometryChange(const QRectF &newGeometry, const QRectF &oldGeom
 #else
     QQuickItem::geometryChange(newGeometry, oldGeometry);
 #endif
+    // qDebug() << "RubberBand::geometryChanged/Change - Function exit";
 }
