@@ -83,6 +83,7 @@ QPixmap renderSVG(const QString &filePath, const QSize &size)
 
 QString timeToString(const QDateTime &time, bool normalFormat)
 {
+    // qDebug() << "Converting time to string";
     QString result = normalFormat ? time.toString(DATETIME_FORMAT_NORMAL) : time.toString(DATETIME_FORMAT_EXIF);
     qDebug() << "Converting time:" << time << "to string format:" << (normalFormat ? "normal" : "exif") << "Result:" << result;
     return result;
@@ -90,18 +91,21 @@ QString timeToString(const QDateTime &time, bool normalFormat)
 
 int stringWidth(const QFont &f, const QString &str)
 {
+    // qDebug() << "Calculating string width";
     QFontMetrics fm(f);
     return fm.boundingRect(str).width();
 }
 
 int stringHeight(const QFont &f, const QString &str)
 {
+    // qDebug() << "Calculating string height";
     QFontMetrics fm(f);
     return fm.boundingRect(str).height();
 }
 
 QDateTime stringToDateTime(const QString &time)
 {
+    // qDebug() << "Converting string to date time";
     QDateTime dt = QDateTime::fromString(time, DATETIME_FORMAT_EXIF);
     if (!dt.isValid()) {
         qDebug() << "Failed to parse time with EXIF format, trying normal format:" << time;
@@ -112,6 +116,7 @@ QDateTime stringToDateTime(const QString &time)
 
 void showInFileManager(const QString &path)
 {
+    // qDebug() << "Showing file manager for path:" << path;
     if (path.isEmpty() || !QFile::exists(path)) {
         qWarning() << "Invalid path for file manager:" << path;
         return;
@@ -241,7 +246,7 @@ bool trashFile(const QString &file)
     trashPath = home + "/.local/share/Trash";
     trashInfoPath = trashPath + "/info";
     trashFilesPath = trashPath + "/files";
-    
+
     if (!QDir(trashFilesPath).exists()) {
         qDebug() << "Creating trash files directory:" << trashFilesPath;
         QDir().mkpath(trashFilesPath);
@@ -267,7 +272,7 @@ bool trashFile(const QString &file)
     QString trashname = getNotExistsTrashFileName(originalInfo.fileName());
     QString infopath = trashInfoPath + "/" + trashname + ".trashinfo";
     QString filepath = trashFilesPath + "/" + trashname;
-    
+
     int nr = 1;
     while (QFileInfo(infopath).exists() || QFileInfo(filepath).exists()) {
         nr++;
@@ -389,12 +394,14 @@ QString SpliteText(const QString &text, const QFont &font, int nLabelSize, bool
 
 QString hash(const QString &str)
 {
+    // qDebug() << "Hashing string:" << str;
     return QString(QCryptographicHash::hash(str.toUtf8(),
                                             QCryptographicHash::Md5).toHex());
 }
 
 QString hashByString(const QString &str)
 {
+    // qDebug() << "Hashing string:" << str;
     return QCryptographicHash::hash(str.toUtf8(), QCryptographicHash::Md5).toHex();
 }
 
@@ -419,6 +426,7 @@ QString hashByData(const QString &str)
 
 bool onMountDevice(const QString &path)
 {
+    qDebug() << "Checking if path is on mount device:" << path;
     bool result = (path.startsWith("/media/") || path.startsWith("/run/media/"));
     qDebug() << "Checking if path is on mount device:" << path << "Result:" << result;
     return result;
@@ -455,6 +463,7 @@ QString filePathToThumbnailPath(const QString &filePath, QString dataHash)
 
 QString getDeleteFullPath(const QString &hash, const QString &fileName)
 {
+    // qDebug() << "Getting delete full path for hash:" << hash << "and file name:" << fileName;
     //防止文件过长,采用只用hash的名称;
     return albumGlobal::DELETE_PATH + "/" + hash + "." + QFileInfo(fileName).suffix();
 }
@@ -577,6 +586,33 @@ bool isSupportWallpaper(const QString &path)
     return result;
 }
 
+bool isSupportClassify(const QString &path)
+{
+    bool bRet = false;
+    //路径为空直接跳出
+    if (!path.isEmpty()) {
+        QMimeDatabase db;
+        QMimeType mt = db.mimeTypeForFile(path, QMimeDatabase::MatchContent);
+
+        if (mt.name().startsWith("image/") || mt.name().startsWith("video/x-mng")) {
+            if (!mt.name().startsWith("image/gif") && !mt.name().startsWith("image/tiff")) {
+                bRet = true;
+            }
+        }
+
+        if (!bRet) {
+            QMimeType mt1 = db.mimeTypeForFile(path, QMimeDatabase::MatchExtension);
+            if (mt1.name().startsWith("image/") || mt1.name().startsWith("video/x-mng")) {
+                if (!mt1.name().startsWith("image/gif") && !mt1.name().startsWith("image/tiff")) {
+                    bRet = true;
+                }
+            }
+        }
+    }
+
+    return bRet;
+}
+
 
 //bool        isCommandExist(const QString &command)
 //{
