@@ -29,7 +29,9 @@ namespace image {
 
 const QImage scaleImage(const QString &path, const QSize &size)
 {
+    qDebug() << "Scaling image:" << path << "to size:" << size;
     if (!imageSupportRead(path)) {
+        qWarning() << "Image format not supported for scaling:" << path;
         return QImage();
     }
     /*lmh0724使用USE_UNIONIMAGE*/
@@ -41,9 +43,10 @@ const QImage scaleImage(const QString &path, const QSize &size)
 //        qDebug() << errMsg;
 //    }
     if (!LibUnionImage_NameSpace::loadStaticImageFromFile(path, tImg, errMsg)) {
-        qDebug() << errMsg;
+        qWarning() << "Failed to load image for scaling:" << path << "Error:" << errMsg;
     }
     if (tImg.size() != size) { //调用加速接口失败，主动进行缩放
+        qDebug() << "Scaling image from" << tImg.size() << "to" << size;
         tImg = tImg.scaled(size);
     }
     return tImg;
@@ -51,6 +54,7 @@ const QImage scaleImage(const QString &path, const QSize &size)
 
 const QDateTime getCreateDateTime(const QString &path)
 {
+    qDebug() << "Getting creation date time for:" << path;
     QDateTime dt; /*= libexif::getCreateDateTime(path);*/
 
     // fallback to metadata.
@@ -61,6 +65,7 @@ const QDateTime getCreateDateTime(const QString &path)
             s = getAllMetaData(path).value("DateTimeDigitized");
         }
         if (s.isEmpty()) {
+            qDebug() << "No metadata found, using current time";
             s = QDateTime::currentDateTime().toString();
         }
         dt = QDateTime::fromString(s, "yyyy.MM.dd HH:mm:ss");
@@ -68,20 +73,24 @@ const QDateTime getCreateDateTime(const QString &path)
 
     // fallback to file create time.
     if (!dt.isValid()) {
+        qDebug() << "No valid metadata, using file birth time";
         QFileInfo finfo(path);
         dt = finfo.birthTime();
     }
 
     // fallback to today.
     if (!dt.isValid()) {
+        qDebug() << "No valid birth time, using current time";
         dt = QDateTime::currentDateTime();
     }
 
+    qDebug() << "Final creation date time:" << dt;
     return dt;
 }
 
 bool imageSupportRead(const QString &path)
 {
+    qDebug() << "Checking if image format is supported for reading:" << path;
     /*lmh0724使用USE_UNIONIMAGE*/
     //修正论坛上提出的格式判断错误，应该采用真实格式
     //20210220真实格式来做判断
@@ -90,6 +99,7 @@ bool imageSupportRead(const QString &path)
     QStringList errorList;
     errorList << "X3F";
     if (errorList.indexOf(suffix.toUpper()) != -1) {
+        qDebug() << "Format" << suffix << "is in error list, not supported";
         return false;
     }
     return LibUnionImage_NameSpace::unionImageSupportFormat().contains(suffix.toUpper());
@@ -97,12 +107,14 @@ bool imageSupportRead(const QString &path)
 
 bool imageSupportSave(const QString &path)
 {
+    qDebug() << "Checking if image format is supported for saving:" << path;
     /*lmh0724使用USE_UNIONIMAGE*/
     return LibUnionImage_NameSpace::canSave(path);
 }
 
 bool rotate(const QString &path, int degree)
 {
+    qDebug() << "Rotating image:" << path << "by" << degree << "degrees";
     /*lmh0724使用USE_UNIONIMAGE*/
     QString erroMsg;
     return LibUnionImage_NameSpace::rotateImageFIle(degree, path, erroMsg);
@@ -116,6 +128,7 @@ bool rotate(const QString &path, int degree)
  */
 const QPixmap cutSquareImage(const QPixmap &pixmap)
 {
+    qDebug() << "Cutting square image from pixmap of size:" << pixmap.size();
     return Libutils::image::cutSquareImage(pixmap, pixmap.size());
 }
 
@@ -128,6 +141,7 @@ const QPixmap cutSquareImage(const QPixmap &pixmap)
  */
 const QPixmap cutSquareImage(const QPixmap &pixmap, const QSize &size)
 {
+    qDebug() << "Cutting square image from pixmap of size:" << pixmap.size() << "to target size:" << size;
     const qreal ratio = qApp->devicePixelRatio();
     QImage img = pixmap.toImage().scaled(size * ratio,
                                          Qt::KeepAspectRatioByExpanding,
@@ -169,6 +183,7 @@ const QPixmap cutSquareImage(const QPixmap &pixmap, const QSize &size)
  */
 const QFileInfoList getImagesInfo(const QString &dir, bool recursive)
 {
+    qDebug() << "Getting image info from directory:" << dir << "recursive:" << recursive;
     QFileInfoList infos;
 
     if (! recursive) {
@@ -178,6 +193,7 @@ const QFileInfoList getImagesInfo(const QString &dir, bool recursive)
                 infos << info;
             }
         }
+        qDebug() << "Found" << infos.size() << "images in directory";
         return infos;
     }
 
@@ -192,6 +208,7 @@ const QFileInfoList getImagesInfo(const QString &dir, bool recursive)
         }
     }
 
+    qDebug() << "Found" << infos.size() << "images recursively";
     return infos;
 }
 
@@ -208,28 +225,30 @@ int getOrientation(const QString &path)
  */
 const QImage getRotatedImage(const QString &path)
 {
-
-
+    qDebug() << "Getting rotated image for:" << path;
     QImage tImg;
     /*lmh0724使用USE_UNIONIMAGE*/
     QString errMsg;
     QSize realSize;
     if (!LibUnionImage_NameSpace::loadStaticImageFromFile(path, tImg, errMsg)) {
-        qDebug() << errMsg;
+        qWarning() << "Failed to load image for rotation:" << path << "Error:" << errMsg;
     }
     return tImg;
 }
 
 const QMap<QString, QString> getAllMetaData(const QString &path)
 {
+    qDebug() << "Getting all metadata for:" << path;
     /*lmh0724使用USE_UNIONIMAGE*/
     return LibUnionImage_NameSpace::getAllMetaData(path);
 }
 
 const QPixmap cachePixmap(const QString &path)
 {
+    qDebug() << "Getting cached pixmap for:" << path;
     QPixmap pp;
     if (! QPixmapCache::find(path, &pp)) {
+        qDebug() << "Pixmap not found in cache, loading from file";
         pp = QPixmap(path);
         QPixmapCache::insert(path, pp);
     }
@@ -249,6 +268,7 @@ const QString toMd5(const QByteArray &data)
  */
 QMap<QString, QString> thumbnailAttribute(const QUrl  &url)
 {
+    qDebug() << "Getting thumbnail attributes for URL:" << url;
     QMap<QString, QString> set;
 
     if (url.isLocalFile()) {
@@ -265,6 +285,7 @@ QMap<QString, QString> thumbnailAttribute(const QUrl  &url)
             set.insert("Thumb::Image::Width", QString::number(reader.size().width()));
             set.insert("Thumb::Image::Height", QString::number(reader.size().height()));
         }
+        qDebug() << "Generated thumbnail attributes for local file:" << path;
     } else {
         //TODO for other's scheme
     }
@@ -274,6 +295,7 @@ QMap<QString, QString> thumbnailAttribute(const QUrl  &url)
 
 const QString thumbnailCachePath()
 {
+    qDebug() << "Getting thumbnail cache path";
     QString cacheP;
 
     QStringList systemEnvs = QProcess::systemEnvironment();
@@ -292,6 +314,7 @@ const QString thumbnailCachePath()
     QDir().mkpath(thumbCacheP + "/large");
     QDir().mkpath(thumbCacheP + "/fail");
 
+    qDebug() << "Thumbnail cache path:" << thumbCacheP;
     return thumbCacheP;
 }
 
@@ -299,6 +322,7 @@ QMutex mutex;
 const QPixmap getThumbnail(const QString &path, bool cacheOnly)
 {
     QMutexLocker locker(&mutex);
+    qDebug() << "Getting thumbnail for:" << path << "cacheOnly:" << cacheOnly;
     //优先读取自身缓存的图片
 //    if (dApp->m_imagemap.value(path).isNull()) {
 //        return dApp->m_imagemap.value(path);
@@ -309,17 +333,20 @@ const QPixmap getThumbnail(const QString &path, bool cacheOnly)
     const QString encodePath = cacheP + "/large/" + md5s + ".png";
     const QString failEncodePath = cacheP + "/fail/" + md5s + ".png";
     if (QFileInfo(encodePath).exists()) {
+        qDebug() << "Found existing thumbnail at:" << encodePath;
         return QPixmap(encodePath);
     }
     /*lmh0724使用USE_UNIONIMAGE*/
     else if (QFileInfo(failEncodePath).exists()) {
-        qDebug() << "Fail-thumbnail exist, won't regenerate: " ;
+        qDebug() << "Found failed thumbnail, won't regenerate:" << failEncodePath;
         return QPixmap();
     } else {
         // Try to generate thumbnail and load it later
         if (! cacheOnly && generateThumbnail(path)) {
+            qDebug() << "Generated new thumbnail at:" << encodePath;
             return QPixmap(encodePath);
         } else {
+            qDebug() << "No thumbnail available";
             return QPixmap();
         }
     }
@@ -332,6 +359,7 @@ const QPixmap getThumbnail(const QString &path, bool cacheOnly)
  */
 bool generateThumbnail(const QString &path)
 {
+    qDebug() << "Generating thumbnail for:" << path;
     const QUrl url = QUrl::fromLocalFile(path);
     const QString md5 = toMd5(url.toString(QUrl::FullyEncoded).toLocal8Bit());
     const auto attributes = thumbnailAttribute(url);
@@ -349,6 +377,7 @@ bool generateThumbnail(const QString &path)
 
     // Create filed thumbnail
     if (lImg.isNull() || nImg.isNull()) {
+        qWarning() << "Failed to generate thumbnail images for:" << path;
         const QString failedP = cacheP + "/fail/" + md5 + ".png";
         QImage img(1, 1, QImage::Format_ARGB32_Premultiplied);
         const auto keys = attributes.keys();
@@ -356,8 +385,8 @@ bool generateThumbnail(const QString &path)
             img.setText(key, attributes[key]);
         }
 
-        qDebug() << "Save failed thumbnail:" << img.save(failedP,  "png")
-                 << failedP << url;
+        bool saved = img.save(failedP,  "png");
+        qDebug() << "Saved failed thumbnail:" << saved << "at:" << failedP;
         return false;
     } else {
         for (QString key : attributes.keys()) {
@@ -366,16 +395,15 @@ bool generateThumbnail(const QString &path)
         }
         const QString largeP = cacheP + "/large/" + md5 + ".png";
         const QString normalP = cacheP + "/normal/" + md5 + ".png";
-        if (lImg.save(largeP, "png", 50) && nImg.save(normalP, "png", 50)) {
-            return true;
-        } else {
-            return false;
-        }
+        bool success = lImg.save(largeP, "png", 50) && nImg.save(normalP, "png", 50);
+        qDebug() << "Saved thumbnail images:" << success;
+        return success;
     }
 }
 
 const QString thumbnailPath(const QString &path, ThumbnailType type)
 {
+    qDebug() << "Getting thumbnail path for:" << path << "type:" << type;
     const QString cacheP = thumbnailCachePath();
     const QUrl url = QUrl::fromLocalFile(path);
     const QString md5s = toMd5(url.toString(QUrl::FullyEncoded).toLocal8Bit());
@@ -393,11 +421,13 @@ const QString thumbnailPath(const QString &path, ThumbnailType type)
     default:
         break;
     }
+    qDebug() << "Thumbnail path:" << tp;
     return tp;
 }
 
 void removeThumbnail(const QString &path)
 {
+    qDebug() << "Removing thumbnails for:" << path;
     QFile(thumbnailPath(path, ThumbLarge)).remove();
     QFile(thumbnailPath(path, ThumbNormal)).remove();
     QFile(thumbnailPath(path, ThumbFail)).remove();
@@ -405,12 +435,15 @@ void removeThumbnail(const QString &path)
 
 bool thumbnailExist(const QString &path, ThumbnailType type)
 {
+    qDebug() << "Checking if thumbnail exists for:" << path << "type:" << type;
     if (QFileInfo(thumbnailPath(path, type)).exists()
 //            || QFileInfo(thumbnailPath(path, ThumbNormal)).exists()
 //            || QFileInfo(thumbnailPath(path, ThumbFail)).exists()
        ) {
+        qDebug() << "Thumbnail exists:" << true;
         return true;
     } else {
+        qDebug() << "Thumbnail exists:" << false;
         return false;
     }
 }
@@ -439,12 +472,14 @@ static QStringList fromByteArrayList(const QByteArrayList &list)
 */
 QStringList supportedImageFormats()
 {
+    qDebug() << "Getting supported image formats";
     /*lmh0724使用USE_UNIONIMAGE*/
     QStringList list ;
     for (auto str : LibUnionImage_NameSpace::unionImageSupportFormat()) {
         str = "*." + str;
         list += str;
     }
+    qDebug() << "Found" << list.size() << "supported formats";
     return list;
 
 }
@@ -454,6 +489,7 @@ QStringList supportedImageFormats()
 
 bool imageSupportWallPaper(const QString &path)
 {
+    qDebug() << "Checking if image supports wallpaper:" << path;
     bool iRet = false;
     QStringList listsupportWallPaper;
     listsupportWallPaper << "bmp"
@@ -498,6 +534,7 @@ bool imageSupportWallPaper(const QString &path)
 //        }
     }
 
+    qDebug() << "Wallpaper support status:" << iRet;
     return iRet;
 }
 
@@ -523,6 +560,7 @@ bool imageSupportWallPaper(const QString &path)
 
 QString makeVaultLocalPath(const QString &path, const QString &base)
 {
+    qDebug() << "Making vault local path for:" << path << "base:" << base;
     QString basePath = base;
     if (basePath.isEmpty()) {
         basePath = VAULT_DECRYPT_DIR_NAME;
@@ -532,6 +570,7 @@ QString makeVaultLocalPath(const QString &path, const QString &base)
 
 bool isVaultFile(const QString &path)
 {
+    qDebug() << "Checking if file is in vault:" << path;
     bool bVaultFile = false;
     QString rootPath = makeVaultLocalPath("", "");
     if (rootPath.back() == QChar('/')) {
@@ -542,22 +581,26 @@ bool isVaultFile(const QString &path)
         bVaultFile = true;
     }
 
+    qDebug() << "Vault file status:" << bVaultFile;
     return bVaultFile;
 
 }
 bool isCanRemove(const QString &path)
 {
+    qDebug() << "Checking if file can be removed:" << path;
     bool bRet = true;
     QString trashPath = QDir::homePath() + "/.local/share/Trash";
     //新增保险箱的判断,回收站判断
     if (isVaultFile(path) || path.contains(trashPath)) {
         bRet = false;
     }
+    qDebug() << "File can be removed:" << bRet;
     return bRet;
 }
 
 void getAllFileInDir(const QDir &dir, QFileInfoList &result)
 {
+    qDebug() << "Getting all files in directory:" << dir.path();
     QDir root(dir);
     auto list = root.entryInfoList(QDir::Dirs | QDir::Files | QDir::NoDotAndDotDot);
     for (const auto &eachInfo : list) {
@@ -567,10 +610,12 @@ void getAllFileInDir(const QDir &dir, QFileInfoList &result)
             result.push_back(eachInfo);
         }
     }
+    qDebug() << "Found" << result.size() << "files in directory";
 }
 
 QFileInfoList getImagesAndVideoInfo(const QString &dir, bool recursive)
 {
+    qDebug() << "Getting images and video info from directory:" << dir << "recursive:" << recursive;
     QFileInfoList infos;
 
     if (! recursive) {
@@ -582,6 +627,7 @@ QFileInfoList getImagesAndVideoInfo(const QString &dir, bool recursive)
                 infos << info;
             }
         }
+        qDebug() << "Found" << infos.size() << "media files in directory";
         return infos;
     }
 
@@ -596,11 +642,13 @@ QFileInfoList getImagesAndVideoInfo(const QString &dir, bool recursive)
         }
     }
 
+    qDebug() << "Found" << infos.size() << "media files recursively";
     return infos;
 }
 
 QPixmap getDamagePixmap(bool bLight)
 {
+    qDebug() << "Getting damage pixmap, light mode:" << bLight;
     static QPixmap pix_light, pix_dark;
     if (bLight) {
         if (pix_light.isNull())
@@ -615,15 +663,15 @@ QPixmap getDamagePixmap(bool bLight)
 
 bool isVideo(QString path)
 {
+    qDebug() << "Checking if file is video:" << path;
     QFileInfo temDir(path);
     QString fileName = temDir.suffix().toLower(); //扩展名
 
     // ts文件可能为翻译文件，使用QMimeDataBase::mimeTypeForFile做精确判断，判断是否为视频
     if (fileName == "ts") {
-        if (QMimeDatabase().mimeTypeForFile(path).name() == "video/mp2t")
-            return true;
-        else
-            return false;
+        bool isVideo = QMimeDatabase().mimeTypeForFile(path).name() == "video/mp2t";
+        qDebug() << "TS file video status:" << isVideo;
+        return isVideo;
     }
 
     return m_videoFiletypes.contains(fileName);
